# Roborock

<p align="center">
  <a href="https://pypi.org/project/python-roborock/">
    <img src="https://img.shields.io/pypi/v/python-roborock.svg?logo=python&logoColor=fff&style=flat-square" alt="PyPI Version">
  </a>
  <img src="https://img.shields.io/pypi/pyversions/python-roborock.svg?style=flat-square&logo=python&amp;logoColor=fff" alt="Supported Python versions">
  <img src="https://img.shields.io/pypi/l/python-roborock.svg?style=flat-square" alt="License">
</p>

Roborock library for online and offline control of your vacuums.

## Installation

Install this via pip (or your favourite package manager):

`pip install python-roborock`

## Functionality

This package can encrypt and decrypt the following commands:
    
- GET_CLEAN_RECORD
- GET_CONSUMABLE
- GET_MULTI_MAPS_LIST
- APP_START
- APP_PAUSE
- APP_STOP
- APP_CHARGE
- APP_SPOT
- FIND_ME
- RESUME_ZONED_CLEAN
- RESUME_SEGMENT_CLEAN 
- SET_CUSTOM_MODE
- SET_MOP_MODE
- SET_WATER_BOX_CUSTOM_MODE
- RESET_CONSUMABLE
- LOAD_MULTI_MAP
- APP_RC_START
- APP_RC_END
- APP_RC_MOVE
- APP_GOTO_TARGET
- APP_SEGMENT_CLEAN
- APP_ZONED_CLEAN
- APP_GET_DRYER_SETTING
- APP_SET_DRYER_SETTING
- APP_START_WASH
- APP_STOP_WASH
- GET_DUST_COLLECTION_MODE
- SET_DUST_COLLECTION_MODE
- GET_SMART_WASH_PARAMS
- SET_SMART_WASH_PARAMS
- GET_WASH_TOWEL_MODE
- SET_WASH_TOWEL_MODE
- SET_CHILD_LOCK_STATUS
- GET_CHILD_LOCK_STATUS
- START_WASH_THEN_CHARGE
- GET_CURRENT_SOUND
- GET_SERIAL_NUMBER
- GET_TIMEZONE
- GET_SERVER_TIMER
- GET_CUSTOMIZE_CLEAN_MODE
- GET_CLEAN_SEQUENCE
- SET_FDS_ENDPOINT
- ENABLE_LOG_UPLOAD
- APP_WAKEUP_ROBOT
- GET_LED_STATUS
- GET_FLOW_LED_STATUS
- SET_FLOW_LED_STATUS
- GET_SOUND_PROGRESS
- GET_SOUND_VOLUME
- TEST_SOUND_VOLUME
- CHANGE_SOUND_VOLUME
- GET_CARPET_MODE
- SET_CARPET_MODE
- GET_CARPET_CLEAN_MODE
- SET_CARPET_CLEAN_MODE
- UPD_SERVER_TIMER
- SET_SERVER_TIMER
- APP_GET_INIT_STATUS
- SET_APP_TIMEZONE
- GET_NETWORK_INFO



## Credits

Thanks @rovo89 for https://gist.github.com/rovo89/dff47ed19fca0dfdda77503e66c2b7c7 And thanks @PiotrMachowski for https://github.com/PiotrMachowski/Home-Assistant-custom-components-Xiaomi-Cloud-Map-Extractor


